#
# spec file for package ghc-commonmark
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name commonmark
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.6.1
Release:        1.1
Summary:        Pure Haskell commonmark parser
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unicode-data-devel
BuildRequires:  ghc-unicode-data-prof
BuildRequires:  ghc-unicode-transforms-devel
BuildRequires:  ghc-unicode-transforms-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
This library provides the core data types and functions for parsing commonmark
(<https://spec.commonmark.org>). The parser is fully commonmark-compliant and
passes the test suite. It is designed to be customizable and easily extensible.
To customize the output, create an AST, or support a new output format, one
need only define some new typeclass instances. It is also easy to add new
syntax elements or modify existing ones.

Accurate information about source positions is available for all block and
inline elements. Thus the library can be used to create an accurate syntax
highlighter or an editor with live preview.

The parser has been designed for robust performance even in pathological cases
that tend to cause stack overflows or exponential slowdowns in other parsers,
with parsing speed that varies linearly with input length.

Related packages:

- commonmark-extensions (which defines a number of syntax extensions) -
commonmark-pandoc (which allows using this parser to create a Pandoc structure)
- commonmark-cli (a command-line tool for converting and syntax-highlighting
commonmark documents).

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.md changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Oct  5 2024 Peter Simons <psimons@suse.com>
- Update commonmark to version 0.2.6.1.
  [#]# 0.2.6.1
  * Fix parsing of link destinations that look like `code` or
    HTML (#136, Michael Howell).  This affects parsing of things
    like `` [link](`)`x` ``.
* Mon Mar 11 2024 Peter Simons <psimons@suse.com>
- Update commonmark to version 0.2.6.
  [#]# 0.2.6
  * Make list tightness match the reference implementation closer (#150,
    Michael Howell). This solves the problem where blank lines in the middle
    of a list are attributed to the list itself instead of the item, making its
    parent list become spuriously loose.
  * Fix bug with entities inside link destinations (#149).
    The bug affects cases like this: `[link](\&#33;)`; the backslash
    escape was being ignored here.
  * Commonmark.Entity: export `pEntity` [API change].
* Thu Feb 15 2024 Peter Simons <psimons@suse.com>
- Update commonmark to version 0.2.5.1.
  [#]# 0.2.5.1
  * Replace `source` with `search` in list of block tags.
    This is a spec 0.31 change that was forgotten in the last release.
* Mon Jan 29 2024 Peter Simons <psimons@suse.com>
- Update commonmark to version 0.2.5.
  [#]# 0.2.5
  * Fix HTML comment parser to conform to 0.31.2 spec.
  * Update spec.txt tests to commonmark-spec 0.31.2.
  * Match HTML declaration blocks with lowercase letters
    (Michael Howell).
  * Specifically track the position where enders end (Michael Howell).
* Mon Dec 11 2023 Peter Simons <psimons@suse.com>
- Update commonmark to version 0.2.4.1.
  [#]# 0.2.4.1
  * Commonmark.Html: Add `aria-hidden`, `d`, and `viewBox` to allowed attributes list.
  * Correctly merge list blanks with non-list blanks (#133, Michael Howell).
  * Do not look for backslashed hard breaks in link titles (#130, Michael Howell).
  * Work around ghc bug with `-K` RTS options, to set the stack space properly
    for tests (#129). See https://gitlab.haskell.org/ghc/ghc/-/issues/10445.
  * Revert block state completely if lazy line (#126). This fixes an issue with
    lazily-wrapped footnotes.
  * Avoid adding trailing newline to list block if it's already there
    (Michael Howell). This fixes tight/loose classification in a few
    cases.
  * Fix incorrectly parsing links with nested `[]` (Michael Howell).
* Fri Oct 27 2023 Peter Simons <psimons@suse.com>
- Update commonmark to version 0.2.4.
  [#]# 0.2.4
  * Do not parse hard line breaks in fenced codeblock info (#116,
    Michael Howell). This change makes commonmark-hs conform to the spec
    and behave like other implementations when an info string in a code
    block ends with a backslash.
  * [API change] Commonmark.Inlines now exports `pEscapedSymbol`
    (#116, Michael Howell).
  * Tokenize combining marks as WordChars not Symbol (#114).
* Sun Jun 25 2023 Peter Simons <psimons@suse.com>
- Update commonmark to version 0.2.3.
  [#]# 0.2.3
  * Re-export Text.Parsec.Pos from Commonmark.Types (Fraser
    Tweedale, #106).
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sat Apr  2 2022 Peter Simons <psimons@suse.com>
- Update commonmark to version 0.2.2.
  [#]# 0.2.2
  * Blocks: export `getParentListType` [API change].
  * Require unicode-data >= 0.3.
  * Change `mkFormattingSpecMap` so it integrates different
    FormattingSpecs that use the same character (#87).  Otherwise
    we have problems if you have one formatting spec that
    reacts to single delimiters and another that reacts to
    pairs; if the first fails to match, the fallback behavior
    is produced and the second never matches.
  * Use unicode-data's faster versions of Data.Char functions.
    This speeds up benchmarks for tokenize considerably; little difference
    in other benchmarks.  unicode-data is already a transitive dependency,
    via unicode-transforms.
  * Increase strictness in tokenize/go.
  * Remove legacy cpp needed to support ghc < 8.4.
* Mon Nov  1 2021 psimons@suse.com
- Update commonmark to version 0.2.1.1.
  [#]# 0.2.1.1
  * Fix bug in `prettyShow` for `SourceRange` (#80).
    The bug led to an infinite loop in certain cases.
* Mon Jun 21 2021 psimons@suse.com
- Update commonmark to version 0.2.1.
  [#]# 0.2.1
  * Use official 0.30 spec.txt.
  * Update HTML block parser for recent spec changes.
  * Fix test case from commonmark/cmark#383.  We need to index the list
    of stack bottoms not just by the length mod 3 of the closer but by
    whether it can be an opener, since this goes into the calculation of
    whether the delimiters can match.
* Sat May 29 2021 psimons@suse.com
- Update commonmark to version 0.2.
  [#]# 0.2
  * Commonmark.Inlines: export LinkInfo(..) [API change].
  * Commonmark.Inlines: export pLink [API chage].
  * Comonmark.ReferenceMap: Add linkPos field to LinkInfo [API change].
  * Commonmark.Tokens: normalize unicode to NFC before tokenizing (#57).
    Normalization might affect detection of flankingness, recognition
    of reference links, etc.
  * Commonmark.Html:  add data-prefix to non-HTML5 attributes, as pandoc does.
  * Remove unnecessary build-depends.
  * Use lightweight tasty-bench instead of criterion for benchmarks.
* Mon Feb  8 2021 psimons@suse.com
- Update commonmark to version 0.1.1.4.
  [#]# 0.1.1.4
  * Fix build with GHC 9.0.1 (Simon Jakobi, #72).
* Tue Jan 12 2021 psimons@suse.com
- Update commonmark to version 0.1.1.3.
  [#]# 0.1.1.3
  * Fix bug in links with spaces at the beginning or end of
    link description (#67).  We were putting flankingness constraints
    on the link delimiters, but this isn't requried by the spec.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sat Nov  7 2020 psimons@suse.com
- Update commonmark to version 0.1.1.2.
  [#]# 0.1.1.2
  * Fix bug in fix to #65 (#66).
  [#]# 0.1.1.1
  * Fixed corner case with link suffix parsing, which could result
    in dropped tokens in certain cases (#65).
* Mon Nov  2 2020 psimons@suse.com
- Update commonmark to version 0.1.1.
  [#]# 0.1.1
  * Export `reverseSubforests` from `Commonmark.Blocks` [API change] (#64).
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Thu Aug  6 2020 psimons@suse.com
- Update commonmark to version 0.1.0.2.
  [#]# 0.1.0.2
  * Fix tight/loose list detection with multiple blank lines at end (#56).
* Tue Aug  4 2020 psimons@suse.com
- Add commonmark at version 0.1.0.1.
